@@ -1,12 +1,12 @@
 use crate::error::warn;
 use anyhow::{anyhow, ensure, Result};
 use dylint_internal::{
-    cargo::SanitizeEnvironment,
     env::{self, var},
-    Command,
+    rustup::{toolchain_path, SanitizeEnvironment},
 };
 use semver::Version;
 use std::{
+    env::consts,
     fs::{copy, create_dir_all, write},
     path::{Path, PathBuf},
     process::Stdio,
@@ -74,7 +74,7 @@ pub fn get(opts: &crate::Dylint, toolchain: &str) -> Result<PathBuf> {
     }
 
     let driver = driver_dir.join("dylint-driver");
-    if !driver.exists() || is_outdated(opts, &driver)? {
+    if !driver.exists() || is_outdated(opts, toolchain, &driver)? {
         build(opts, toolchain, &driver)?;
     }
 
@@ -87,7 +87,7 @@ fn dylint_drivers() -> Result<PathBuf> {
         ensure!(dylint_drivers.is_dir());
         Ok(dylint_drivers.to_path_buf())
     } else {
-        let home = var(env::HOME)?;
+        let home = dirs::home_dir().ok_or_else(|| anyhow!("Could not find HOME directory"))?;
         let dylint_drivers = Path::new(&home).join(".dylint_drivers");
         if !dylint_drivers.is_dir() {
             create_dir_all(&dylint_drivers)?;
@@ -97,8 +97,9 @@ fn dylint_drivers() -> Result<PathBuf> {
     }
 }
 
-fn is_outdated(opts: &crate::Dylint, driver: &Path) -> Result<bool> {
-    let output = Command::new(driver).args(&["-V"]).output()?;
+fn is_outdated(opts: &crate::Dylint, toolchain: &str, driver: &Path) -> Result<bool> {
+    let mut command = dylint_internal::driver(toolchain, driver)?;
+    let output = command.args(&["-V"]).output()?;
     let stdout = std::str::from_utf8(&output.stdout)?;
     let theirs = stdout
         .trim_end()
@@ -144,6 +145,7 @@ fn build(opts: &crate::Dylint, toolchain: &str, driver: &Path) -> Result<()> {
             .expect("Could not get parent directory")
             .join("driver")
             .to_string_lossy()
+            .replace('\\', "\\\\")
     );
 
     let dylint_driver_spec = format!("{}{}", version_spec, path_spec);
@@ -157,10 +159,21 @@ fn build(opts: &crate::Dylint, toolchain: &str, driver: &Path) -> Result<()> {
     create_dir_all(&src)?;
     write(&src.join("main.rs"), MAIN_RS)?;
 
+    let toolchain_path = toolchain_path(package)?;
+
+    // smoelius: The commented code was the old behavior. It would cause the driver to have rpaths
+    // like `$ORIGIN/../../`... (see https://github.com/trailofbits/dylint/issues/54). The new
+    // behavior causes the driver to have absolute rpaths.
+    // let rustflags = "-C rpath=yes";
+    let rustflags = format!(
+        "-C link-args=-Wl,-rpath,{}/lib",
+        toolchain_path.to_string_lossy()
+    );
+
     let mut command = dylint_internal::build();
     command
         .sanitize_environment()
-        .envs(vec![(env::RUSTFLAGS, "-C rpath=yes")])
+        .envs(vec![(env::RUSTFLAGS, rustflags)])
         .current_dir(&package);
     if opts.quiet {
         command.stderr(Stdio::null());
@@ -168,10 +181,11 @@ fn build(opts: &crate::Dylint, toolchain: &str, driver: &Path) -> Result<()> {
     command.success()?;
 
     copy(
-        package
-            .join("target")
-            .join("debug")
-            .join(format!("dylint_driver-{}", toolchain)),
+        package.join("target").join("debug").join(format!(
+            "dylint_driver-{}{}",
+            toolchain,
+            consts::EXE_SUFFIX
+        )),
         driver,
     )?;
 
