@@ -3,14 +3,11 @@
 #![deny(clippy::panic)]
 
 use anyhow::{anyhow, bail, ensure, Context, Result};
-use dylint_internal::{
-    env::{self, var},
-    Command,
-};
+use dylint_internal::env::{self, var};
 use lazy_static::lazy_static;
 use std::{
     collections::{BTreeMap, BTreeSet},
-    env::consts,
+    env::{consts, split_paths},
     ffi::OsStr,
     fmt::Debug,
     fs::read_dir,
@@ -96,8 +93,7 @@ fn dylint_library_paths() -> Result<Vec<(PathBuf, bool)>> {
     let mut paths = Vec::new();
 
     if let Ok(val) = var(env::DYLINT_LIBRARY_PATH) {
-        for path in val.split(':') {
-            let path = PathBuf::from(path);
+        for path in split_paths(&val) {
             ensure!(
                 path.is_absolute(),
                 "DYLINT_LIBRARY_PATH contains `{}`, which is not absolute",
@@ -379,7 +375,8 @@ fn list_lints(
 
                     // smoelius: `-W help` is the normal way to list lints, so we can be sure it
                     // gets the lints loaded. However, we don't actually use it to list the lints.
-                    Command::new(driver)
+                    let mut command = dylint_internal::driver(toolchain, &driver)?;
+                    command
                         .envs(vec![
                             (env::DYLINT_LIBS.to_owned(), dylint_libs),
                             (env::DYLINT_LIST.to_owned(), "1".to_owned()),
@@ -468,7 +465,7 @@ mod test {
     #![allow(clippy::unwrap_used)]
 
     use super::*;
-    use dylint_internal::examples;
+    use dylint_internal::{cargo::current_metadata, examples};
     use lazy_static::lazy_static;
     use std::env::set_var;
     use test_env_log::test;
@@ -476,18 +473,8 @@ mod test {
     lazy_static! {
         static ref NAME_TOOLCHAIN_MAP: NameToolchainMap = {
             examples::build().unwrap();
-            let dylint_library_path = examples::iter()
-                .unwrap()
-                .map(|example| {
-                    example
-                        .unwrap()
-                        .join("target")
-                        .join("debug")
-                        .to_string_lossy()
-                        .to_string()
-                })
-                .collect::<Vec<_>>()
-                .join(":");
+            let metadata = current_metadata().unwrap();
+            let dylint_library_path = metadata.target_directory.join("debug");
             set_var(env::DYLINT_LIBRARY_PATH, dylint_library_path);
             name_toolchain_map(&Dylint {
                 no_metadata: true,
