@@ -8,7 +8,7 @@ use cargo::{
     util::{self, Config},
 };
 use cargo_metadata::{Error, Metadata, MetadataCommand};
-use dylint_internal::cargo::SanitizeEnvironment;
+use dylint_internal::rustup::SanitizeEnvironment;
 use glob::glob;
 use if_chain::if_chain;
 use serde::Deserialize;
@@ -133,9 +133,9 @@ fn maybe_build_packages(
     // files sooner.
 
     // smoelius: Why are we doing this complicated dance at all? Because we want to leverage Cargo's
-    // package cache. But we also want to support git repositories with libraries that use different
-    // compiler versions. And we have to work around the fact that "all projects within a workspace
-    // are intended to be built with the same version of the compiler"
+    // download cache. But we also want to support git repositories with libraries that use
+    // different compiler versions. And we have to work around the fact that "all projects within a
+    // workspace are intended to be built with the same version of the compiler"
     // (https://github.com/rust-lang/rustup/issues/1399#issuecomment-383376082).
 
     let package_root_ids = paths
@@ -172,7 +172,6 @@ fn dependency(
     let mut warnings = vec![];
     let features = Features::new(&[], config, &mut warnings)?;
     let mut cx = Context::new(
-        None,
         &mut deps,
         source_id,
         &mut nested_paths,
@@ -318,7 +317,7 @@ fn target_dir(metadata: &Metadata, package_root: &Path, package_id: PackageId) -
 }
 
 // smoelius: `pkg_dir` and `target_short_hash` are based on functions with the same names in
-// https://github.com/rust-lang/cargo/blob/master/src/cargo/core/compiler/context/compilation_files.rs.
+// https://github.com/rust-lang/cargo/blob/master/src/cargo/core/compiler/context/compilation_files.rs
 
 fn pkg_dir(package_root: &Path, pkg_id: PackageId) -> String {
     let name = pkg_id.name();
